@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2012 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: FileCopy.h,v 1.81 2008/11/27 05:56:12 lav Exp $ */
+/* $Id: FileCopy.h,v 1.85 2010/05/20 13:53:15 lav Exp $ */
 
 /*
   classes defined here:
@@ -54,6 +53,7 @@ protected:
    bool can_seek0;
    bool date_set;
    bool do_set_date;
+   bool do_verify;
    bool removing;
    bool file_removed;
 
@@ -90,6 +90,7 @@ public:
    void SetEntitySize(off_t s) { e_size=s; }
 
    void DontCopyDate() { do_set_date=false; }
+   void DontVerify() { do_verify=false; }
    bool NeedDate() { return do_set_date; }
 
    void SetRange(const off_t s,const off_t lim);
@@ -225,10 +226,11 @@ public:
    void SetError(const char *str);
 
    void DontCopyDate() { put->DontCopyDate(); }
+   void DontVerify() { put->DontVerify(); }
    void Ascii() { get->Ascii(); put->Ascii(); }
    void DontFailIfBroken() { fail_if_broken=false; }
    void FailIfCannotSeek() { fail_if_cannot_seek=true; }
-   void SetRange(off_t s,off_t lim) { get->SetRange(s,lim); put->SetRange(s,lim); }
+   void SetRange(off_t s,off_t lim);
    void SetRangeLimit(off_t lim) { get->range_limit=lim; }
    off_t GetRangeStart() { return get->range_start; }
    off_t GetRangeLimit() { return get->range_limit; }
@@ -295,6 +297,7 @@ class FileCopyPeerFA : public FileCopyPeer
 
    time_t try_time;
    int retries;
+   off_t upload_watermark;
 
    int redirections;
 
